@@ -5,6 +5,7 @@ import param
 
 from ..core import util
 from ..core.data import ImageInterface
+from ..core.data.interface import DataError
 from ..core import Dimension, Element2D, Overlay, Dataset
 from ..core.boundingregion import BoundingRegion, BoundingBox
 from ..core.sheetcoords import SheetCoordinateSystem, Slice
@@ -235,6 +236,11 @@ class Image(Dataset, Raster, SheetCoordinateSystem):
             or (isinstance(data, np.ndarray) and data.size == 0)):
             data = np.zeros((2, 2))
         Dataset.__init__(self, data, kdims=kdims, vdims=vdims, extents=extents, **params)
+        if not self.interface.gridded:
+            raise DataError("%s type expects gridded data, %s is columnar."
+                            "To display columnar data as gridded use the HeatMap "
+                            "element or aggregate the data." %
+                            (type(self).__name__, self.interface.__name__))
 
         dim2, dim1 = self.interface.shape(self, gridded=True)[:2]
         if bounds is None:
@@ -349,10 +355,13 @@ class Image(Dataset, Raster, SheetCoordinateSystem):
         # If a 1D cross-section of 2D space return Curve
         shape = self.interface.shape(self, gridded=True)
         if len(samples) == 1:
-            dims = [kd for kd, v in zip(self.kdims, samples[0]) if not np.isscalar(v)]
+            dims = [kd for kd, v in zip(self.kdims, samples[0])
+                    if not (np.isscalar(v) or isinstance(v, util.datetime_types))]
             if len(dims) == 1:
                 kdims = [self.get_dimension(kd) for kd in dims]
-                sel = {kd.name: s for kd, s in zip(self.kdims, samples[0])}
+                sample = tuple(np.datetime64(s) if isinstance(s, util.datetime_types) else s
+                               for s in samples[0])
+                sel = {kd.name: s for kd, s in zip(self.kdims, sample)}
                 dims = [kd for kd, v in sel.items() if not np.isscalar(v)]
                 selection = self.select(**sel)
                 selection = tuple(selection.columns(kdims+self.vdims).values())
@@ -365,6 +374,10 @@ class Image(Dataset, Raster, SheetCoordinateSystem):
             kdims = self.kdims
 
         xs, ys = zip(*samples)
+        if isinstance(xs[0], util.datetime_types):
+            xs = np.array(xs).astype(np.datetime64)
+        if isinstance(ys[0], util.datetime_types):
+            ys = np.array(ys).astype(np.datetime64)
         yidx, xidx = self.sheet2matrixidx(np.array(xs), np.array(ys))
         yidx = shape[0]-yidx-1
 
@@ -624,8 +637,13 @@ class QuadMesh(Raster):
     vdims = param.List(default=[Dimension('z')], bounds=(1,1))
 
     def __init__(self, data, kdims=None, vdims=None, **params):
-        data = self._process_data(data)
-        Element2D.__init__(self, data, kdims=kdims, vdims=vdims, **params)
+        data, kwargs = self._process_data(data)
+        params = dict(kwargs, **params)
+        if kdims is not None:
+            params['kdims'] = kdims
+        if vdims is not None:
+            params['vdims'] = vdims
+        Element2D.__init__(self, data, **params)
         self.data = self._validate_data(self.data)
         self._grid = self.data[0].ndim == 1
 
@@ -639,15 +657,17 @@ class QuadMesh(Raster):
             x = data.dimension_values(0, expanded=False)
             y = data.dimension_values(1, expanded=False)
             zarray = data.dimension_values(2, flat=False)
+            params = util.get_param_values(data)
         else:
-            data = tuple(np.array(el) for el in data)
+            data = tuple(np.asarray(el) for el in data)
             x, y, zarray = data
+            params = {}
         ys, xs = zarray.shape
         if x.ndim == 1 and len(x) == xs:
             x = compute_edges(x)
         if y.ndim == 1 and len(y) == ys:
             y = compute_edges(y)
-        return (x, y, zarray)
+        return (x, y, zarray), params
 
 
     @property
